<?php

/**
 * @file
 * A few tweaks to make Tutor statistics integrate better with Views.
 */

/**
 * Implements hook_views_data_alter(). 
 */
function tutor_statistics_views_data_alter(&$info) {
  // Make the  'nid' field behave as a node id in Views.
  $info['eck_tutor_statistics']['nid']['field']['handler'] = 'views_handler_field_node';
  $info['eck_tutor_statistics']['nid']['argument']['handler'] = 'views_handler_argument_node_nid';
  
  // Provide a relationship to the actual node table.
  $info['eck_tutor_statistics']['nid']['relationship'] = array(
    'title' => t('Question node'),
    'help' => t('The node containing the question for this statistics entity.'),
    'base' => 'node',
    'base field' => 'nid',
    'handler' => 'views_handler_relationship',
    'label' => t('Node'),
  );

  // Provide a relationship from the node table to the Tutor statistics.
  $info['node']['eck_tutor_statistics'] = array(
    'title' => t('Tutor statistics'),
    'help' => t('Provides a relationship to statistics entities for Tutor questions.'),
    'relationship' => array(
      'group' => t('Tutor question statistics'),
      'title' => t('Answer statistics'),
      'help' => t('The statistics entities corresponding to a node.'),
      'base' => 'eck_tutor_statistics',
      'base field' => 'nid',
      'relationship field' => 'nid',
      'handler' => 'tutor_statistics_handler_relationship_user',
      'label' => t('Statistics'),
    ),
  );
  
  // Make the 'uid' field behave as a user id in Views.
  $info['eck_tutor_statistics']['uid']['field']['handler'] = 'views_handler_field_user';
  $info['eck_tutor_statistics']['uid']['argument']['handler'] = 'views_handler_argument_user_uid';
  $info['eck_tutor_statistics']['uid']['filter']['handler'] = 'views_handler_filter_user_name';

  // Provide a relationship to the actual users table.
  $info['eck_tutor_statistics']['uid']['relationship'] = array(
    'title' => t('Answering user'),
    'help' => t('The user whose answer provided the statistics.'),
    'base' => 'users',
    'base field' => 'uid',
    'handler' => 'views_handler_relationship',
    'label' => t('Account'),
  );

  // Provide a relationship from the users table to the Tutor statistics.
  $info['users']['eck_tutor_statistics'] = array(
    'title' => t('Tutor statistics'),
    'help' => t('Provides a relationship to statistics entities for Tutor questions.'),
    'relationship' => array(
      'group' => t('Tutor question statistics'),
      'title' => t('Answer statistics'),
      'help' => t('The statistics entities generated by a user.'),
      'base' => 'eck_tutor_statistics',
      'base field' => 'uid',
      'relationship field' => 'uid',
      'handler' => 'views_handler_relationship',
      'label' => t('Statistics'),
    ),
  );
}
